@@ -74,10 +74,11 @@ static const argp_option options[] =
       " propositions", 0},
     /**************************************************/
     { nullptr, 0, nullptr, 0, "Fine tuning:", 10 },
-    { "algo", OPT_ALGO, "ds|sd|lar|lar.old", 0,
+    { "algo", OPT_ALGO, "sd|ds|ps|lar|lar.old", 0,
       "choose the algorithm for synthesis:\n"
-      " - sd:   split then determinize with Safra (default)\n"
-      " - ds:   determinize (Safra) then split\n"
+      " - sd:   translate to tgba, split, then determinize (default)\n"
+      " - ds:   translate to tgba, determinize, then split\n"
+      " - ps:   translate to dpa, then split\n"
       " - lar:  translate to a deterministic automaton with arbitrary"
       " acceptance condition, then use LAR to turn to parity,"
       " then split\n"
@@ -98,6 +99,8 @@ static const argp_option options[] =
       "not output)", 0 },
     /**************************************************/
     { nullptr, 0, nullptr, 0, "Miscellaneous options:", -1 },
+    { "extra-options", 'x', "OPTS", 0,
+        "fine-tuning options (see spot-x (7))", 0 },
     { nullptr, 0, nullptr, 0, nullptr, 0 },
   };
 
@@ -124,6 +127,7 @@ static const char* opt_csv = nullptr;
 static bool opt_print_pg = false;
 static bool opt_real = false;
 static bool opt_print_aiger = false;
+static spot::option_map extra_options;
 
 static double trans_time = 0.0;
 static double split_time = 0.0;
@@ -131,11 +135,14 @@ static double paritize_time = 0.0;
 static double bgame_time = 0.0;
 static double solve_time = 0.0;
 static double strat2aut_time = 0.0;
+static unsigned nb_states_dpa = 0;
+static unsigned nb_states_parity_game = 0;
 
 enum solver
 {
   DET_SPLIT,
   SPLIT_DET,
+  DPA_SPLIT,
   LAR,
   LAR_OLD,
 };
@@ -144,6 +151,7 @@ static char const *const solver_names[] =
   {
    "ds",
    "sd",
+   "ps",
    "lar",
    "lar.old"
   };
@@ -152,6 +160,7 @@ static char const *const solver_args[] =
 {
   "detsplit", "ds",
   "splitdet", "sd",
+  "dpasplit", "ps",
   "lar",
   "lar.old",
   nullptr
@@ -160,6 +169,7 @@ static solver const solver_types[] =
 {
   DET_SPLIT, DET_SPLIT,
   SPLIT_DET, SPLIT_DET,
+  DPA_SPLIT, DPA_SPLIT,
   LAR,
   LAR_OLD,
 };
@@ -310,7 +320,8 @@ namespace
               out << ",\"strat2aut_time\"";
             out << ",\"realizable\"";
           }
-        out << '\n';
+        out << ",\"dpa_num_states\",\"parity_game_num_states\""
+            << '\n';
       }
     std::ostringstream os;
     os << f;
@@ -327,7 +338,9 @@ namespace
           out << ',' << strat2aut_time;
         out << ',' << realizable;
       }
-    out << '\n';
+    out << ',' << nb_states_dpa
+        << ',' << nb_states_parity_game
+        << '\n';
     outf.close(opt_csv);
   }
 
@@ -354,10 +367,21 @@ namespace
       spot::stopwatch sw;
       bool want_time = verbose || opt_csv;
 
-      if (opt_solver == LAR || opt_solver == LAR_OLD)
+      switch (opt_solver)
         {
+        case LAR:
+        case LAR_OLD:
           trans_.set_type(spot::postprocessor::Generic);
           trans_.set_pref(spot::postprocessor::Deterministic);
+          break;
+        case DPA_SPLIT:
+          trans_.set_type(spot::postprocessor::ParityMaxOdd);
+          trans_.set_pref(spot::postprocessor::Deterministic
+                          | spot::postprocessor::Colored);
+          break;
+        case DET_SPLIT:
+        case SPLIT_DET:
+          break;
         }
 
       if (want_time)
@@ -384,8 +408,12 @@ namespace
       if (want_time)
         trans_time = sw.stop();
       if (verbose)
-        std::cerr << "translating formula done in "
-                  << trans_time << " seconds\n";
+        {
+          std::cerr << "translating formula done in "
+                    << trans_time << " seconds\n";
+          std::cerr << "automaton has " << aut->num_states()
+                    << " states and " << aut->num_sets() << " colors\n";
+        }
 
       spot::twa_graph_ptr dpa = nullptr;
       switch (opt_solver)
@@ -419,6 +447,29 @@ namespace
                           << tmp->num_states() << " states\n";
               break;
             }
+          case DPA_SPLIT:
+            {
+              if (want_time)
+                sw.start();
+              aut->merge_states();
+              if (want_time)
+                paritize_time = sw.stop();
+              if (verbose)
+                std::cerr << "simplification done in " << paritize_time
+                          << " seconds\nDPA has " << aut->num_states()
+                          << " states\n";
+              if (want_time)
+                sw.start();
+              dpa = split_2step(aut, all_inputs);
+              spot::colorize_parity_here(dpa, true);
+              if (want_time)
+                split_time = sw.stop();
+              if (verbose)
+                std::cerr << "split inputs and outputs done in " << split_time
+                          << " seconds\nautomaton has "
+                          << dpa->num_states() << " states\n";
+              break;
+            }
           case SPLIT_DET:
             {
               if (want_time)
@@ -486,6 +537,7 @@ namespace
               break;
             }
         }
+      nb_states_dpa = dpa->num_states();
       if (want_time)
         sw.start();
       auto owner = complete_env(dpa);
@@ -511,6 +563,7 @@ namespace
         solve_time = sw.stop();
       if (verbose)
         std::cerr << "parity game solved in " << solve_time << " seconds\n";
+      nb_states_parity_game = pg.num_states();
       timer.stop();
       if (winning_region[1].count(pg.get_init_state_number()))
         {
@@ -600,6 +653,13 @@ parse_opt(int key, char* arg, struct argp_state*)
     case OPT_VERBOSE:
       verbose = true;
       break;
+    case 'x':
+      {
+        const char* opt = extra_options.parse_options(arg);
+        if (opt)
+          error(2, 0, "failed to parse --options near '%s'", opt);
+      }
+      break;
     }
   END_EXCEPTION_PROTECT;
   return 0;
@@ -609,6 +669,11 @@ int
 main(int argc, char **argv)
 {
   return protected_main(argv, [&] {
+      extra_options.set("simul", 0);
+      extra_options.set("ba-simul", 0);
+      extra_options.set("det-simul", 0);
+      extra_options.set("tls-impl", 1);
+      extra_options.set("wdba-minimize", 2);
       const argp ap = { options, parse_opt, nullptr,
                         argp_program_doc, children, nullptr, nullptr };
       if (int err = argp_parse(&ap, argc, argv, ARGP_NO_HELP, nullptr, nullptr))
@@ -618,8 +683,11 @@ main(int argc, char **argv)
       // Setup the dictionary now, so that BuDDy's initialization is
       // not measured in our timings.
       spot::bdd_dict_ptr dict = spot::make_bdd_dict();
-      spot::translator trans(dict);
+      spot::translator trans(dict, &extra_options);
       ltl_processor processor(trans, input_aps, output_aps);
+
+      // Diagnose unused -x options
+      extra_options.report_unused_options();
       return processor.run();
     });
 }
