@@ -22,6 +22,7 @@
 #include <cstddef>
 #include <cassert>
 #include <spot/misc/intvcomp.hh>
+#include <iostream>
 
 namespace spot
 {
@@ -38,7 +39,7 @@ namespace spot
   //  00  encodes "value 0"
   //  010 encodes "value 1"
   //  011 encodes "a value in [2..5]" followed by 2 bits
-  //  100 encodes "a value in [6..22]" followed by 4 bits
+  //  100 encodes "a value in [6..21]" followed by 4 bits
   //  101 encodes "repeat prev. value [1..8] times" followed by 3 bits count
   //  110 encodes "repeat prev. value [9..40] times" followed by 5 bits count
   //  111 encodes "an int value" followed by 32 bits
@@ -74,14 +75,14 @@ namespace spot
             self().push_bits(0x3, 3, 0x7);
             self().push_bits(val - 2, 2, 0x3);
           }
-        else if (val >= 6 && val <= 22)
+        else if (val >= 6 && val <= 21)
           {
             self().push_bits(0x4, 3, 0x7);
             self().push_bits(val - 6, 4, 0xf);
           }
         else
           {
-            assert(val > 22);
+            assert(val > 21);
             self().push_bits(0x7, 3, 0x7);
             self().push_bits(val, 32, -1U);
           }
@@ -195,7 +196,7 @@ namespace spot
 
       void push_data(unsigned int i)
       {
-        result_->push_back(i);
+        result_->emplace_back(i);
       }
 
       const std::vector<unsigned int>*
@@ -245,7 +246,7 @@ namespace spot
 
       void push_data(unsigned int i)
       {
-        output_.push_back(i);
+        output_.emplace_back(i);
       }
 
       bool have_data() const
@@ -542,7 +543,7 @@ namespace spot
       void push_data(int i)
       {
         prev_ = i;
-        result_.push_back(i);
+        result_.emplace_back(i);
         --size_;
       }
 
@@ -550,7 +551,7 @@ namespace spot
       {
         size_ -= i;
         while (i--)
-          result_.push_back(prev_);
+          result_.emplace_back(prev_);
       }
 
       bool have_comp_data() const
