@@ -1,5 +1,5 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2009-2017 Laboratoire de Recherche et Développement de
+// Copyright (C) 2009-2018 Laboratoire de Recherche et Développement de
 // l'Epita (LRDE)
 //
 // This file is part of Spot, a model checking library.
@@ -17,6 +17,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "config.h"
 #include <map>
 #include <algorithm>
 #include <iterator>
@@ -131,7 +132,7 @@ namespace spot
     {
       taa_tgba::transition* t = new taa_tgba::transition;
       t->condition = bddtrue;
-      t->acceptance_conditions = 0U;
+      t->acceptance_conditions = {};
       t->dst = new taa_tgba::state_set;
       succ_.emplace_back(t);
       return;
@@ -154,7 +155,7 @@ namespace spot
     {
       taa_tgba::transition* t = new taa_tgba::transition;
       t->condition = bddtrue;
-      t->acceptance_conditions = 0U;
+      t->acceptance_conditions = {};
       taa_tgba::state_set* ss = new taa_tgba::state_set;
 
       unsigned p;
