@@ -1,6 +1,6 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2015-2018 Laboratoire de Recherche et Développement
-// de l'Epita (LRDE).
+// Copyright (C) 2015-2018, 2020 Laboratoire de Recherche et
+// Développement de l'Epita (LRDE).
 //
 // This file is part of Spot, a model checking library.
 //
@@ -63,12 +63,18 @@ namespace spot
             bool_subst = true;
           }
       }
-    if (!bool_subst)
-      for (auto& t: aut->edges())
-        t.cond = bdd_replace(t.cond, pairs);
-    else
-      for (auto& t: aut->edges())
-        t.cond = bdd_veccompose(t.cond, pairs);
+
+    bool need_cleanup = false;
+    typedef bdd (*op_t)(const bdd&, bddPair*);
+    op_t op = bool_subst ?
+      static_cast<op_t>(bdd_veccompose) : static_cast<op_t>(bdd_replace);
+    for (auto& t: aut->edges())
+      {
+        bdd c = (*op)(t.cond, pairs);
+        t.cond = c;
+        if (c == bddfalse)
+          need_cleanup = true;
+      }
 
     // Erase all the old variables that are not reused in the new set.
     // (E.g., if we relabel a&p0 into p0&p1 we should not unregister
@@ -76,5 +82,13 @@ namespace spot
     for (auto v: vars)
       if (newvars.find(v) == newvars.end())
         aut->unregister_ap(v);
+
+    // If some of the edges were relabeled false, we need to clean the
+    // automaton.
+    if (need_cleanup)
+      {
+        aut->merge_edges();     // remove any edge labeled by 0
+        aut->purge_dead_states(); // remove useless states
+      }
   }
 }
