@@ -17,6 +17,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "config.h"
 #include <spot/twaalgos/totgba.hh>
 #include <spot/twaalgos/remfin.hh>
 #include <spot/twaalgos/cleanacc.hh>
@@ -25,11 +26,11 @@
 #include <deque>
 #include <tuple>
 
-#define DEBUG 0
-#if DEBUG
-#define debug std::cerr
+#define TRACE 0
+#if TRACE
+#define trace std::cerr
 #else
-#define debug while (0) std::cerr
+#define trace while (0) std::cerr
 #endif
 
 namespace spot
@@ -75,57 +76,56 @@ namespace spot
       void
       split_dnf_clauses(const acc_cond::acc_code& code)
       {
-        bool one_conjunction = false;
-        const acc_cond::acc_op root_op = code.back().sub.op;
-        auto s = code.back().sub.size;
-        while (s)
+        auto pos = &code.back();
+        if (pos->sub.op == acc_cond::acc_op::Or)
+          --pos;
+        auto start = &code.front();
+        while (pos > start)
           {
-            --s;
-            if (code[s].sub.op == acc_cond::acc_op::And
-                || ((one_conjunction = root_op == acc_cond::acc_op::And)))
+            const unsigned short size = pos[0].sub.size;
+            if (pos[0].sub.op == acc_cond::acc_op::And)
               {
-                s = one_conjunction ? s + 1 : s;
-                const unsigned short size = code[s].sub.size;
-                acc_cond::mark_t fin = 0u;
-                acc_cond::mark_t inf = 0u;
-                for (unsigned i = 1; i <= size; i += 2)
+                acc_cond::mark_t fin = {};
+                acc_cond::mark_t inf = {};
+                for (int i = 1; i <= (int)size; i += 2)
                   {
-                    if (code[s-i].sub.op == acc_cond::acc_op::Fin)
-                      fin |= code[s-i-1].mark;
-                    else if (code[s-i].sub.op == acc_cond::acc_op::Inf)
-                      inf |= code[s-i-1].mark;
+                    if (pos[-i].sub.op == acc_cond::acc_op::Fin)
+                      fin |= pos[-i - 1].mark;
+                    else if (pos[-i].sub.op == acc_cond::acc_op::Inf)
+                      inf |= pos[-i - 1].mark;
                     else
                       SPOT_UNREACHABLE();
                   }
                 all_clauses_.emplace_back(fin, inf);
                 set_to_keep_.emplace_back(fin | inf);
-                s -= size;
               }
-            else if (code[s].sub.op == acc_cond::acc_op::Fin) // Fin
+            else if (pos[0].sub.op == acc_cond::acc_op::Fin) // Fin
               {
-                auto m1 = code[--s].mark;
+                auto m1 = pos[-1].mark;
                 for (unsigned int s : m1.sets())
                   {
-                    all_clauses_.emplace_back(acc_cond::mark_t({s}), 0u);
+                    all_clauses_.emplace_back(acc_cond::mark_t({s}),
+                                              acc_cond::mark_t({}));
                     set_to_keep_.emplace_back(acc_cond::mark_t({s}));
                   }
               }
-            else if (code[s].sub.op == acc_cond::acc_op::Inf) // Inf
+            else if (pos[0].sub.op == acc_cond::acc_op::Inf) // Inf
               {
-                auto m2 = code[--s].mark;
-                all_clauses_.emplace_back(0u, m2);
+                auto m2 = pos[-1].mark;
+                all_clauses_.emplace_back(acc_cond::mark_t({}), m2);
                 set_to_keep_.emplace_back(m2);
               }
             else
               {
                 SPOT_UNREACHABLE();
               }
+            pos -= size + 1;
           }
-#if DEBUG
-        debug << "\nPrinting all clauses\n";
+#if TRACE
+        trace << "\nPrinting all clauses\n";
         for (unsigned i = 0; i < all_clauses_.size(); ++i)
           {
-            debug << i << " Fin:" << all_clauses_[i].first << " Inf:"
+            trace << i << " Fin:" << all_clauses_[i].first << " Inf:"
                   << all_clauses_[i].second << '\n';
           }
 #endif
@@ -182,7 +182,7 @@ namespace spot
           {
             if (all_clauses_[clause].second)
               {
-                acc_cond::mark_t m = 0u;
+                acc_cond::mark_t m = {};
                 for (unsigned set = 0; set < max_set_in_; ++set)
                   if (all_clauses_[clause].second.has(set))
                     {
@@ -193,11 +193,11 @@ namespace spot
               }
             else
               {
-                set_to_add_.emplace_back(0u);
+                set_to_add_.emplace_back(acc_cond::mark_t({}));
               }
           }
 
-        all_set_to_add_ = 0u;
+        all_set_to_add_ = {};
         for (unsigned s = 0; s < max_set_in_; ++s)
           if (all_inf_.has(s))
             {
@@ -238,16 +238,18 @@ namespace spot
                   res[scc].push_back(clause);
               }
           }
-#if DEBUG
-        debug << "accepting clauses\n";
+#if TRACE
+        trace << "accepting clauses\n";
         for (unsigned i = 0; i < res.size(); ++i)
           {
-            debug << "scc(" << i << ") --> ";
+            trace << "scc(" << i << ") -->";
             for (auto elt : res[i])
-              debug << elt << ',';
-            debug << '\n'
+              trace << ' ' << elt;
+            if (si_.is_rejecting_scc(i))
+              trace << " rej";
+            trace << '\n';
           }
-        debug << '\n';
+        trace << '\n';
 #endif
       }
 
@@ -257,7 +259,7 @@ namespace spot
       void
       add_state(unsigned st)
       {
-        debug << "add_state(" << st << ")\n";
+        trace << "add_state(" << st << ")\n";
         if (st_repr_[st].empty())
           {
             unsigned st_scc = si_.scc_of(st);
@@ -270,7 +272,7 @@ namespace spot
 
             else
               st_repr_[st].emplace_back(-1U, res_->new_state());
-            debug << "added\n";
+            trace << "added\n";
           }
       }
 
@@ -317,7 +319,7 @@ namespace spot
           init_st_in_(in->get_init_state_number()),
           init_reachable_(is_init_reachable())
       {
-        debug << "State based ? " << state_based_ << '\n';
+        trace << "State based ? " << state_based_ << '\n';
         std::tie(all_inf_, all_fin_) = code.used_inf_fin_sets();
         split_dnf_clauses(code);
         find_set_to_add();
@@ -339,6 +341,7 @@ namespace spot
           {
             if (!si_.is_useful_scc(scc))
               continue;
+            trace << "scc #" << scc << '\n';
 
             bool rej_scc = acc_clauses_[scc].empty();
             for (auto st : si_.states_of(scc))
@@ -346,7 +349,7 @@ namespace spot
                 add_state(st);
                 for (const auto& e : in_->out(st))
                   {
-                    debug << "working_on_edge(" << st << ',' << e.dst << ")\n";
+                    trace << "working_on_edge(" << st << ',' << e.dst << ")\n";
 
                     unsigned dst_scc = si_.scc_of(e.dst);
                     if (!si_.is_useful_scc(dst_scc))
@@ -357,7 +360,7 @@ namespace spot
                     if (st == init_st_in_)
                       {
                         for (const auto& p_dst : st_repr_[e.dst])
-                          res_->new_edge(res_init_, p_dst.second, e.cond, 0u);
+                          res_->new_edge(res_init_, p_dst.second, e.cond, {});
                         if (!init_reachable_)
                           continue;
                       }
@@ -366,7 +369,7 @@ namespace spot
                       for (const auto& p_src : st_repr_[st])
                         for (const auto& p_dst : st_repr_[e.dst])
                           {
-                            debug << "repr(" << p_src.second << ','
+                            trace << "repr(" << p_src.second << ','
                                   << p_dst.second << ")\n";
 
                             if (same_scc && p_src.first == p_dst.first)
@@ -377,16 +380,16 @@ namespace spot
                               res_->new_edge(p_src.second, p_dst.second, e.cond,
                                              state_based_ ?
                                                get_edge_mark(e.acc, p_src.first)
-                                             : 0u);
+                                             : acc_cond::mark_t({}));
                           }
                     else
                       {
                         assert(st_repr_[st].size() == 1);
                         unsigned src = st_repr_[st][0].second;
 
-                        acc_cond::mark_t m = 0u;
+                        acc_cond::mark_t m = {};
                         if (same_scc || state_based_)
-                          m = all_set_to_add_;
+                          m = e.acc | all_set_to_add_;
 
                         for (const auto& p_dst : st_repr_[e.dst])
                           res_->new_edge(src, p_dst.second, e.cond, m);
@@ -450,7 +453,7 @@ namespace spot
       acc_cond::mark_t pend;
       unsigned s;
 
-      st2gba_state(unsigned st, acc_cond::mark_t bv = -1U):
+      st2gba_state(unsigned st, acc_cond::mark_t bv = acc_cond::mark_t::all()):
         pend(bv), s(st)
       {
       }
@@ -494,7 +497,7 @@ namespace spot
           bool inor = pos->sub.op == acc_cond::acc_op::Or;
           if (inor)
             --pos;
-          acc_cond::mark_t m = 0U;
+          acc_cond::mark_t m = {};
           while (pos > term_end)
             {
               assert(pos->sub.op == acc_cond::acc_op::Inf);
@@ -553,15 +556,17 @@ namespace spot
     unsigned p = inf.count();
     // At some point we will remove anything that is not used as Inf.
     acc_cond::mark_t to_strip = in->acc().all_sets() - inf;
-    acc_cond::mark_t inf_alone = 0U;
-    acc_cond::mark_t fin_alone = 0U;
+    acc_cond::mark_t inf_alone = {};
+    acc_cond::mark_t fin_alone = {};
 
     if (!p)
       return remove_fin(in);
 
     unsigned numsets = in->acc().num_sets();
-    std::vector<acc_cond::mark_t> fin_to_infpairs(numsets, 0U);
-    std::vector<acc_cond::mark_t> inf_to_finpairs(numsets, 0U);
+    std::vector<acc_cond::mark_t> fin_to_infpairs(numsets,
+                                                  acc_cond::mark_t({}));
+    std::vector<acc_cond::mark_t> inf_to_finpairs(numsets,
+                                                  acc_cond::mark_t({}));
     for (auto pair: pairs)
       {
         if (pair.fin)
@@ -580,7 +585,7 @@ namespace spot
     // fin_alone, but we also have fin_to_infpair[0] = {1}.  This should
     // really be simplified to Fin(0).
     for (auto mark: fin_alone.sets())
-      fin_to_infpairs[mark] = 0U;
+      fin_to_infpairs[mark] = {};
 
     scc_info si(in, scc_info_options::NONE);
 
@@ -597,7 +602,7 @@ namespace spot
         // Fin sets that are alone either because the acceptance
         // condition has no matching Inf, or because the SCC does not
         // intersect the matching Inf.
-        acc_cond::mark_t fin_wo_inf = 0U;
+        acc_cond::mark_t fin_wo_inf = {};
         for (unsigned mark: acc_fin.sets())
           if (!fin_to_infpairs[mark] || (fin_to_infpairs[mark] - acc_inf))
             fin_wo_inf.set(mark);
@@ -605,13 +610,13 @@ namespace spot
         // Inf sets that *do* have a matching Fin in the acceptance
         // condition but without matching Fin in the SCC: they can be
         // considered as always present in the SCC.
-        acc_cond::mark_t inf_wo_fin = 0U;
+        acc_cond::mark_t inf_wo_fin = {};
         for (unsigned mark: inf.sets())
           if (inf_to_finpairs[mark] && (inf_to_finpairs[mark] - acc_fin))
             inf_wo_fin.set(mark);
 
         sccfi.emplace_back(fin_wo_inf, inf_wo_fin,
-                           acc_fin == 0U, acc_inf == 0U);
+                           !acc_fin, !acc_inf);
       }
 
     auto out = make_twa_graph(in->get_dict());
@@ -636,7 +641,7 @@ namespace spot
     bool sbacc = in->prop_state_acc().is_true();
 
     // States of the original automaton are marked with s.pend == -1U.
-    const acc_cond::mark_t orig_copy(-1U);
+    const acc_cond::mark_t orig_copy = acc_cond::mark_t::all();
 
     while (!todo.empty())
       {
@@ -657,7 +662,7 @@ namespace spot
         for (auto& t: in->out(s.s))
           {
             acc_cond::mark_t pend = s.pend;
-            acc_cond::mark_t acc = 0U;
+            acc_cond::mark_t acc = {};
 
             bool maybe_acc = maybe_acc_scc && (scc_src == si.scc_of(t.dst));
             if (pend != orig_copy)
@@ -724,7 +729,7 @@ namespace spot
             // this has to occur at least once per cycle.
             if (pend == orig_copy && (t.src >= t.dst) && maybe_acc && !no_fin)
               {
-                acc_cond::mark_t stpend = 0U;
+                acc_cond::mark_t stpend = {};
                 if (sbacc)
                   {
                     auto a = in->state_acc_sets(t.dst);
@@ -819,7 +824,7 @@ namespace spot
     // state without successor.
     if (cnf.is_f())
       {
-        assert(cnf.front().mark == 0U);
+        assert(!cnf.front().mark);
         res = make_twa_graph(aut->get_dict());
         res->set_init_state(res->new_state());
         res->prop_state_acc(true);
@@ -837,7 +842,7 @@ namespace spot
     for (auto& t: res->edges())
       {
         acc_cond::mark_t cur_m = t.acc;
-        acc_cond::mark_t new_m = 0U;
+        acc_cond::mark_t new_m = {};
         for (unsigned n = 0; n < nterms; ++n)
           if (cur_m & terms[n])
             new_m.set(n);
@@ -863,7 +868,7 @@ namespace spot
       std::vector<std::pair<acc_cond::mark_t, acc_cond::mark_t>> res;
       if (acc.empty())
         {
-          res.emplace_back(0U, 0U);
+          res.emplace_back(acc_cond::mark_t({}), acc_cond::mark_t({}));
           return res;
         }
       auto pos = &acc.back();
@@ -877,15 +882,15 @@ namespace spot
               // We have only a Fin term, without Inf.  In this case
               // only, the Fin() may encode a disjunction of sets.
               for (auto s: pos[-1].mark.sets())
-                res.emplace_back(acc_cond::mark_t({s}), 0U);
+                res.emplace_back(acc_cond::mark_t({s}), acc_cond::mark_t({}));
               pos -= pos->sub.size + 1;
             }
           else
             {
               // We have a conjunction of Fin and Inf sets.
               auto end = pos - pos->sub.size - 1;
-              acc_cond::mark_t fin = 0U;
-              acc_cond::mark_t inf = 0U;
+              acc_cond::mark_t fin = {};
+              acc_cond::mark_t inf = {};
               while (pos > end)
                 {
                   switch (pos->sub.op)
@@ -969,7 +974,7 @@ namespace spot
               fin_set = next_set++;
             }
 
-          acc_cond::mark_t infsets = 0U;
+          acc_cond::mark_t infsets = {};
 
           if (share_inf)
             for (auto s: i.second.sets())
@@ -1018,7 +1023,7 @@ namespace spot
       res->set_acceptance(next_set, code);
       for (auto& e: res->edges())
         {
-          acc_cond::mark_t m = 0U;
+          acc_cond::mark_t m = {};
           for (auto s: e.acc.sets())
             m |= rename[s];
           e.acc = m;
