@@ -1,5 +1,5 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2013-2016, 2018 Laboratoire de Recherche et
+// Copyright (C) 2013-2016, 2018-2019 Laboratoire de Recherche et
 // Developement de l'Epita (LRDE).
 //
 // This file is part of Spot, a model checking library.
@@ -28,7 +28,7 @@
 static void
 syntax(char *prog)
 {
-  std::cerr << prog << " formula" << std::endl;
+  std::cerr << prog << " formula\n";
   exit(2);
 }
 
