@@ -1,5 +1,5 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2014-2017 Laboratoire de Recherche et Développement
+// Copyright (C) 2014-2018 Laboratoire de Recherche et Développement
 // de l'Epita (LRDE).
 //
 // This file is part of Spot, a model checking library.
@@ -17,7 +17,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
+#include "config.h"
 #include <iostream>
 #include <spot/twa/twagraph.hh>
 #include <spot/twaalgos/dot.hh>
@@ -38,12 +38,12 @@ static void f1()
   auto s1 = tg->new_state();
   auto s2 = tg->new_state();
   auto s3 = tg->new_state();
-  tg->new_edge(s1, s1, bddfalse, 0U);
-  tg->new_edge(s1, s2, p1, 0U);
+  tg->new_edge(s1, s1, bddfalse, {});
+  tg->new_edge(s1, s2, p1, {});
   tg->new_edge(s1, s3, p2, tg->acc().mark(1));
   tg->new_edge(s2, s3, p1 & p2, tg->acc().mark(0));
   tg->new_edge(s3, s1, p1 | p2, spot::acc_cond::mark_t({0, 1}));
-  tg->new_edge(s3, s2, p1 >> p2, 0U);
+  tg->new_edge(s3, s2, p1 >> p2, {});
   tg->new_edge(s3, s3, bddtrue, spot::acc_cond::mark_t({0, 1}));
 
   spot::print_dot(std::cout, tg);
@@ -66,7 +66,7 @@ static void f1()
 
   spot::acc_cond::mark_t all({0, 1});
   tg->new_edge(s3, s1, p1 | p2, all);
-  tg->new_edge(s3, s2, p1 >> p2, 0U);
+  tg->new_edge(s3, s2, p1 >> p2, {});
   tg->new_edge(s3, s1, bddtrue, all);
 
   std::cerr << tg->num_edges() << '\n';
@@ -105,7 +105,19 @@ static void f2()
   }
   tg->set_init_state(s3);
   spot::print_dot(std::cout, tg);
-  tg->purge_unreachable_states();
+  void (*action)(const std::vector<unsigned>&, void*) =
+    [](const std::vector<unsigned>& newst, void*)
+    {
+      for (unsigned i = 0; i != newst.size(); ++i)
+        {
+          std::cout << i << " -> ";
+          if (newst[i] == -1U)
+            std::cout << "deleted" << std::endl;
+          else
+            std::cout << newst[i] << std::endl;
+        }
+    };
+  tg->purge_unreachable_states(&action);
   spot::print_dot(std::cout, tg);
 }
 
@@ -146,10 +158,31 @@ static void f4()
   spot::print_hoa(std::cout, tg, "1.1") << '\n';
 }
 
+// Test merge_states()
+static void f5()
+{
+  auto d = spot::make_bdd_dict();
+  auto tg = make_twa_graph(d);
+
+  auto s1 = tg->new_state();
+  auto s2 = tg->new_state();
+  auto s3 = tg->new_state();
+
+  tg->set_init_state(s3);
+  tg->new_edge(s1, s2, bddtrue);
+  tg->new_edge(s2, s2, bddtrue);
+  tg->new_edge(s3, s2, bddtrue);
+
+  tg->merge_states();
+
+  spot::print_hoa(std::cout, tg) << '\n';
+}
+
 int main()
 {
   f1();
   f2();
   f3();
   f4();
+  f5();
 }
